#[repr(C)]pub struct ClockGetInputResponse {
pub index: u32,
}Fields
index: u32Trait Implementations
Sourceimpl Clone for ClockGetInputResponse
impl Clone for ClockGetInputResponse
Sourcefn clone(&self) -> ClockGetInputResponse
fn clone(&self) -> ClockGetInputResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClockGetInputResponse
impl Debug for ClockGetInputResponse
Sourceimpl<'a, ___E> Encode<ClockGetInputResponse, ___E> for &'a ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockGetInputResponse, ___E> for &'a ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetInputResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetInputResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockGetInputResponse, ___E> for ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockGetInputResponse, ___E> for ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockGetInputResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockGetInputResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetInputResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetInputResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockGetInputResponse>, ___E> for &'a ClockGetInputResponse
impl<'a, ___E> EncodeOption<Box<'static, ClockGetInputResponse>, ___E> for &'a ClockGetInputResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetInputResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetInputResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockGetInputResponse>, ___E> for ClockGetInputResponse
impl<___E> EncodeOption<Box<'static, ClockGetInputResponse>, ___E> for ClockGetInputResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetInputResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetInputResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ClockGetInputResponse> for ClockGetInputResponse
impl FromWire<ClockGetInputResponse> for ClockGetInputResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetInputResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetInputResponse, Self>
Sourcefn from_wire(wire: ClockGetInputResponse) -> Self
fn from_wire(wire: ClockGetInputResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockGetInputResponse> for ClockGetInputResponse
impl FromWireRef<ClockGetInputResponse> for ClockGetInputResponse
Sourcefn from_wire_ref(wire: &ClockGetInputResponse) -> Self
fn from_wire_ref(wire: &ClockGetInputResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ClockGetInputResponse
impl Hash for ClockGetInputResponse
Sourceimpl Ord for ClockGetInputResponse
impl Ord for ClockGetInputResponse
Sourcefn cmp(&self, other: &ClockGetInputResponse) -> Ordering
fn cmp(&self, other: &ClockGetInputResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockGetInputResponse
impl PartialEq for ClockGetInputResponse
Sourcefn eq(&self, other: &ClockGetInputResponse) -> bool
fn eq(&self, other: &ClockGetInputResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockGetInputResponse
impl PartialOrd for ClockGetInputResponse
impl Copy for ClockGetInputResponse
impl Eq for ClockGetInputResponse
impl StructuralPartialEq for ClockGetInputResponse