#[repr(C)]pub struct ClockGetNumInputsResponse {
pub n: u32,
}Fields
n: u32Trait Implementations
Sourceimpl Clone for ClockGetNumInputsResponse
impl Clone for ClockGetNumInputsResponse
Sourcefn clone(&self) -> ClockGetNumInputsResponse
fn clone(&self) -> ClockGetNumInputsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClockGetNumInputsResponse
impl Debug for ClockGetNumInputsResponse
Sourceimpl<'a, ___E> Encode<ClockGetNumInputsResponse, ___E> for &'a ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockGetNumInputsResponse, ___E> for &'a ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetNumInputsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetNumInputsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockGetNumInputsResponse, ___E> for ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockGetNumInputsResponse, ___E> for ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockGetNumInputsResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockGetNumInputsResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetNumInputsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetNumInputsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockGetNumInputsResponse>, ___E> for &'a ClockGetNumInputsResponsewhere
___E: Encoder + ?Sized,
&'a ClockGetNumInputsResponse: Encode<ClockGetNumInputsResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ClockGetNumInputsResponse>, ___E> for &'a ClockGetNumInputsResponsewhere
___E: Encoder + ?Sized,
&'a ClockGetNumInputsResponse: Encode<ClockGetNumInputsResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetNumInputsResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetNumInputsResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockGetNumInputsResponse>, ___E> for ClockGetNumInputsResponse
impl<___E> EncodeOption<Box<'static, ClockGetNumInputsResponse>, ___E> for ClockGetNumInputsResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetNumInputsResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetNumInputsResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
impl FromWire<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetNumInputsResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetNumInputsResponse, Self>
Sourcefn from_wire(wire: ClockGetNumInputsResponse) -> Self
fn from_wire(wire: ClockGetNumInputsResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
impl FromWireRef<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
Sourcefn from_wire_ref(wire: &ClockGetNumInputsResponse) -> Self
fn from_wire_ref(wire: &ClockGetNumInputsResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ClockGetNumInputsResponse
impl Hash for ClockGetNumInputsResponse
Sourceimpl Ord for ClockGetNumInputsResponse
impl Ord for ClockGetNumInputsResponse
Sourcefn cmp(&self, other: &ClockGetNumInputsResponse) -> Ordering
fn cmp(&self, other: &ClockGetNumInputsResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockGetNumInputsResponse
impl PartialEq for ClockGetNumInputsResponse
Sourcefn eq(&self, other: &ClockGetNumInputsResponse) -> bool
fn eq(&self, other: &ClockGetNumInputsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockGetNumInputsResponse
impl PartialOrd for ClockGetNumInputsResponse
impl Copy for ClockGetNumInputsResponse
impl Eq for ClockGetNumInputsResponse
impl StructuralPartialEq for ClockGetNumInputsResponse