pub struct ClockGetPropertiesResponse {
pub id: u32,
pub name: String,
}Fields
id: u32name: StringTrait Implementations
Sourceimpl Clone for ClockGetPropertiesResponse
impl Clone for ClockGetPropertiesResponse
Sourcefn clone(&self) -> ClockGetPropertiesResponse
fn clone(&self) -> ClockGetPropertiesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClockGetPropertiesResponse
impl Debug for ClockGetPropertiesResponse
Sourceimpl<'a, ___E> Encode<ClockGetPropertiesResponse<'static>, ___E> for &'a ClockGetPropertiesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ClockGetPropertiesResponse<'static>, ___E> for &'a ClockGetPropertiesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetPropertiesResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetPropertiesResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockGetPropertiesResponse<'static>, ___E> for ClockGetPropertiesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ClockGetPropertiesResponse<'static>, ___E> for ClockGetPropertiesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetPropertiesResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetPropertiesResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockGetPropertiesResponse<'static>>, ___E> for &'a ClockGetPropertiesResponsewhere
___E: Encoder + ?Sized,
&'a ClockGetPropertiesResponse: Encode<ClockGetPropertiesResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ClockGetPropertiesResponse<'static>>, ___E> for &'a ClockGetPropertiesResponsewhere
___E: Encoder + ?Sized,
&'a ClockGetPropertiesResponse: Encode<ClockGetPropertiesResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetPropertiesResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetPropertiesResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockGetPropertiesResponse<'static>>, ___E> for ClockGetPropertiesResponsewhere
___E: Encoder + ?Sized,
ClockGetPropertiesResponse: Encode<ClockGetPropertiesResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ClockGetPropertiesResponse<'static>>, ___E> for ClockGetPropertiesResponsewhere
___E: Encoder + ?Sized,
ClockGetPropertiesResponse: Encode<ClockGetPropertiesResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetPropertiesResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetPropertiesResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ClockGetPropertiesResponse<'de>> for ClockGetPropertiesResponse
impl<'de> FromWire<ClockGetPropertiesResponse<'de>> for ClockGetPropertiesResponse
Sourcefn from_wire(wire: ClockGetPropertiesResponse<'de>) -> Self
fn from_wire(wire: ClockGetPropertiesResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ClockGetPropertiesResponse<'de>> for ClockGetPropertiesResponse
impl<'de> FromWireRef<ClockGetPropertiesResponse<'de>> for ClockGetPropertiesResponse
Sourcefn from_wire_ref(wire: &ClockGetPropertiesResponse<'de>) -> Self
fn from_wire_ref(wire: &ClockGetPropertiesResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ClockGetPropertiesResponse
impl Hash for ClockGetPropertiesResponse
Sourceimpl Ord for ClockGetPropertiesResponse
impl Ord for ClockGetPropertiesResponse
Sourcefn cmp(&self, other: &ClockGetPropertiesResponse) -> Ordering
fn cmp(&self, other: &ClockGetPropertiesResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockGetPropertiesResponse
impl PartialEq for ClockGetPropertiesResponse
Sourcefn eq(&self, other: &ClockGetPropertiesResponse) -> bool
fn eq(&self, other: &ClockGetPropertiesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockGetPropertiesResponse
impl PartialOrd for ClockGetPropertiesResponse
impl Eq for ClockGetPropertiesResponse
impl StructuralPartialEq for ClockGetPropertiesResponse