#[repr(C)]pub struct ClockIsEnabledResponse {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for ClockIsEnabledResponse
impl Clone for ClockIsEnabledResponse
Sourcefn clone(&self) -> ClockIsEnabledResponse
fn clone(&self) -> ClockIsEnabledResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClockIsEnabledResponse
impl Debug for ClockIsEnabledResponse
Sourceimpl<'a, ___E> Encode<ClockIsEnabledResponse, ___E> for &'a ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockIsEnabledResponse, ___E> for &'a ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockIsEnabledResponse, ___E> for ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockIsEnabledResponse, ___E> for ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockIsEnabledResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockIsEnabledResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockIsEnabledResponse>, ___E> for &'a ClockIsEnabledResponse
impl<'a, ___E> EncodeOption<Box<'static, ClockIsEnabledResponse>, ___E> for &'a ClockIsEnabledResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockIsEnabledResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockIsEnabledResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockIsEnabledResponse>, ___E> for ClockIsEnabledResponse
impl<___E> EncodeOption<Box<'static, ClockIsEnabledResponse>, ___E> for ClockIsEnabledResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockIsEnabledResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockIsEnabledResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ClockIsEnabledResponse> for ClockIsEnabledResponse
impl FromWire<ClockIsEnabledResponse> for ClockIsEnabledResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockIsEnabledResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockIsEnabledResponse, Self>
Sourcefn from_wire(wire: ClockIsEnabledResponse) -> Self
fn from_wire(wire: ClockIsEnabledResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockIsEnabledResponse> for ClockIsEnabledResponse
impl FromWireRef<ClockIsEnabledResponse> for ClockIsEnabledResponse
Sourcefn from_wire_ref(wire: &ClockIsEnabledResponse) -> Self
fn from_wire_ref(wire: &ClockIsEnabledResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ClockIsEnabledResponse
impl Hash for ClockIsEnabledResponse
Sourceimpl Ord for ClockIsEnabledResponse
impl Ord for ClockIsEnabledResponse
Sourcefn cmp(&self, other: &ClockIsEnabledResponse) -> Ordering
fn cmp(&self, other: &ClockIsEnabledResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockIsEnabledResponse
impl PartialEq for ClockIsEnabledResponse
Sourcefn eq(&self, other: &ClockIsEnabledResponse) -> bool
fn eq(&self, other: &ClockIsEnabledResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockIsEnabledResponse
impl PartialOrd for ClockIsEnabledResponse
impl Copy for ClockIsEnabledResponse
impl Eq for ClockIsEnabledResponse
impl StructuralPartialEq for ClockIsEnabledResponse