#[repr(C)]pub struct ClockQuerySupportedRateResponse {
pub hz_out: u64,
}Fields
hz_out: u64Trait Implementations
Sourceimpl Clone for ClockQuerySupportedRateResponse
impl Clone for ClockQuerySupportedRateResponse
Sourcefn clone(&self) -> ClockQuerySupportedRateResponse
fn clone(&self) -> ClockQuerySupportedRateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<ClockQuerySupportedRateResponse, ___E> for &'a ClockQuerySupportedRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockQuerySupportedRateResponse, ___E> for &'a ClockQuerySupportedRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockQuerySupportedRateResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockQuerySupportedRateResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockQuerySupportedRateResponse, ___E> for ClockQuerySupportedRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockQuerySupportedRateResponse, ___E> for ClockQuerySupportedRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockQuerySupportedRateResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockQuerySupportedRateResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockQuerySupportedRateResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockQuerySupportedRateResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockQuerySupportedRateResponse>, ___E> for &'a ClockQuerySupportedRateResponsewhere
___E: Encoder + ?Sized,
&'a ClockQuerySupportedRateResponse: Encode<ClockQuerySupportedRateResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ClockQuerySupportedRateResponse>, ___E> for &'a ClockQuerySupportedRateResponsewhere
___E: Encoder + ?Sized,
&'a ClockQuerySupportedRateResponse: Encode<ClockQuerySupportedRateResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockQuerySupportedRateResponse>, ___E> for ClockQuerySupportedRateResponsewhere
___E: Encoder + ?Sized,
ClockQuerySupportedRateResponse: Encode<ClockQuerySupportedRateResponse, ___E>,
impl<___E> EncodeOption<Box<'static, ClockQuerySupportedRateResponse>, ___E> for ClockQuerySupportedRateResponsewhere
___E: Encoder + ?Sized,
ClockQuerySupportedRateResponse: Encode<ClockQuerySupportedRateResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ClockQuerySupportedRateResponse> for ClockQuerySupportedRateResponse
impl FromWire<ClockQuerySupportedRateResponse> for ClockQuerySupportedRateResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateResponse, Self>
Sourcefn from_wire(wire: ClockQuerySupportedRateResponse) -> Self
fn from_wire(wire: ClockQuerySupportedRateResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockQuerySupportedRateResponse> for ClockQuerySupportedRateResponse
impl FromWireRef<ClockQuerySupportedRateResponse> for ClockQuerySupportedRateResponse
Sourcefn from_wire_ref(wire: &ClockQuerySupportedRateResponse) -> Self
fn from_wire_ref(wire: &ClockQuerySupportedRateResponse) -> Self
Converts the given reference to this type.
Sourceimpl Ord for ClockQuerySupportedRateResponse
impl Ord for ClockQuerySupportedRateResponse
Sourcefn cmp(&self, other: &ClockQuerySupportedRateResponse) -> Ordering
fn cmp(&self, other: &ClockQuerySupportedRateResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockQuerySupportedRateResponse
impl PartialEq for ClockQuerySupportedRateResponse
Sourcefn eq(&self, other: &ClockQuerySupportedRateResponse) -> bool
fn eq(&self, other: &ClockQuerySupportedRateResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockQuerySupportedRateResponse
impl PartialOrd for ClockQuerySupportedRateResponse
impl Copy for ClockQuerySupportedRateResponse
impl Eq for ClockQuerySupportedRateResponse
impl StructuralPartialEq for ClockQuerySupportedRateResponse