#[repr(C)]pub struct ClockSetInputRequest {
pub idx: u32,
}Fields
idx: u32Trait Implementations
Sourceimpl Clone for ClockSetInputRequest
impl Clone for ClockSetInputRequest
Sourcefn clone(&self) -> ClockSetInputRequest
fn clone(&self) -> ClockSetInputRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClockSetInputRequest
impl Debug for ClockSetInputRequest
Sourceimpl<'a, ___E> Encode<ClockSetInputRequest, ___E> for &'a ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockSetInputRequest, ___E> for &'a ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockSetInputRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockSetInputRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockSetInputRequest, ___E> for ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockSetInputRequest, ___E> for ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockSetInputRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockSetInputRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockSetInputRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockSetInputRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockSetInputRequest>, ___E> for &'a ClockSetInputRequest
impl<'a, ___E> EncodeOption<Box<'static, ClockSetInputRequest>, ___E> for &'a ClockSetInputRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockSetInputRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockSetInputRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockSetInputRequest>, ___E> for ClockSetInputRequest
impl<___E> EncodeOption<Box<'static, ClockSetInputRequest>, ___E> for ClockSetInputRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockSetInputRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockSetInputRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ClockSetInputRequest> for ClockSetInputRequest
impl FromWire<ClockSetInputRequest> for ClockSetInputRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockSetInputRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockSetInputRequest, Self>
Sourcefn from_wire(wire: ClockSetInputRequest) -> Self
fn from_wire(wire: ClockSetInputRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockSetInputRequest> for ClockSetInputRequest
impl FromWireRef<ClockSetInputRequest> for ClockSetInputRequest
Sourcefn from_wire_ref(wire: &ClockSetInputRequest) -> Self
fn from_wire_ref(wire: &ClockSetInputRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ClockSetInputRequest
impl Hash for ClockSetInputRequest
Sourceimpl Ord for ClockSetInputRequest
impl Ord for ClockSetInputRequest
Sourcefn cmp(&self, other: &ClockSetInputRequest) -> Ordering
fn cmp(&self, other: &ClockSetInputRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockSetInputRequest
impl PartialEq for ClockSetInputRequest
Sourcefn eq(&self, other: &ClockSetInputRequest) -> bool
fn eq(&self, other: &ClockSetInputRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockSetInputRequest
impl PartialOrd for ClockSetInputRequest
impl Copy for ClockSetInputRequest
impl Eq for ClockSetInputRequest
impl StructuralPartialEq for ClockSetInputRequest