#[repr(C)]pub struct ClockGetInputResponse {
pub index: Uint32,
}Expand description
The wire type corresponding to ClockGetInputResponse.
Fields
index: Uint32Trait Implementations
Sourceimpl Clone for ClockGetInputResponse
impl Clone for ClockGetInputResponse
Sourcefn clone(&self) -> ClockGetInputResponse
fn clone(&self) -> ClockGetInputResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ClockGetInputResponse
impl Constrained for ClockGetInputResponse
Sourceimpl Debug for ClockGetInputResponse
impl Debug for ClockGetInputResponse
Sourceimpl<___D> Decode<___D> for ClockGetInputResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ClockGetInputResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ClockGetInputResponse, ___E> for &'a ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockGetInputResponse, ___E> for &'a ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetInputResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetInputResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockGetInputResponse, ___E> for ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockGetInputResponse, ___E> for ClockGetInputResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockGetInputResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockGetInputResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetInputResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetInputResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ClockGetInputResponse, ___E> for ClockGetInputResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<ClockGetInputResponse, ___E> for ClockGetInputResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetInputResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetInputResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ClockGetInputResponse> for ClockGetInputResponse
impl FromWire<ClockGetInputResponse> for ClockGetInputResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetInputResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetInputResponse, Self>
Sourcefn from_wire(wire: ClockGetInputResponse) -> Self
fn from_wire(wire: ClockGetInputResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockGetInputResponse> for ClockGetInputResponse
impl FromWireRef<ClockGetInputResponse> for ClockGetInputResponse
Sourcefn from_wire_ref(wire: &ClockGetInputResponse) -> Self
fn from_wire_ref(wire: &ClockGetInputResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ClockGetInputResponse
impl IntoNatural for ClockGetInputResponse
Sourcetype Natural = ClockGetInputResponse
type Natural = ClockGetInputResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ClockGetInputResponse
impl Wire for ClockGetInputResponse
Sourcetype Narrowed<'de> = ClockGetInputResponse
type Narrowed<'de> = ClockGetInputResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.