#[repr(C)]pub struct ClockIsEnabledResponse {
pub enabled: bool,
}Expand description
The wire type corresponding to ClockIsEnabledResponse.
Fields
enabled: boolTrait Implementations
Sourceimpl Clone for ClockIsEnabledResponse
impl Clone for ClockIsEnabledResponse
Sourcefn clone(&self) -> ClockIsEnabledResponse
fn clone(&self) -> ClockIsEnabledResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ClockIsEnabledResponse
impl Constrained for ClockIsEnabledResponse
Sourceimpl Debug for ClockIsEnabledResponse
impl Debug for ClockIsEnabledResponse
Sourceimpl<___D> Decode<___D> for ClockIsEnabledResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ClockIsEnabledResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ClockIsEnabledResponse, ___E> for &'a ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockIsEnabledResponse, ___E> for &'a ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockIsEnabledResponse, ___E> for ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockIsEnabledResponse, ___E> for ClockIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockIsEnabledResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockIsEnabledResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ClockIsEnabledResponse, ___E> for ClockIsEnabledResponse<T0>
impl<___E, T0> Encode<ClockIsEnabledResponse, ___E> for ClockIsEnabledResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ClockIsEnabledResponse> for ClockIsEnabledResponse
impl FromWire<ClockIsEnabledResponse> for ClockIsEnabledResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockIsEnabledResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockIsEnabledResponse, Self>
Sourcefn from_wire(wire: ClockIsEnabledResponse) -> Self
fn from_wire(wire: ClockIsEnabledResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockIsEnabledResponse> for ClockIsEnabledResponse
impl FromWireRef<ClockIsEnabledResponse> for ClockIsEnabledResponse
Sourcefn from_wire_ref(wire: &ClockIsEnabledResponse) -> Self
fn from_wire_ref(wire: &ClockIsEnabledResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ClockIsEnabledResponse
impl IntoNatural for ClockIsEnabledResponse
Sourcetype Natural = ClockIsEnabledResponse
type Natural = ClockIsEnabledResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ClockIsEnabledResponse
impl Wire for ClockIsEnabledResponse
Sourcetype Narrowed<'de> = ClockIsEnabledResponse
type Narrowed<'de> = ClockIsEnabledResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.