#[repr(C)]pub struct ClockQuerySupportedRateRequest {
pub hz_in: Uint64,
}Expand description
The wire type corresponding to ClockQuerySupportedRateRequest.
Fields
hz_in: Uint64Trait Implementations
Sourceimpl Clone for ClockQuerySupportedRateRequest
impl Clone for ClockQuerySupportedRateRequest
Sourcefn clone(&self) -> ClockQuerySupportedRateRequest
fn clone(&self) -> ClockQuerySupportedRateRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ClockQuerySupportedRateRequest
impl Constrained for ClockQuerySupportedRateRequest
Sourceimpl<___D> Decode<___D> for ClockQuerySupportedRateRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ClockQuerySupportedRateRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ClockQuerySupportedRateRequest, ___E> for &'a ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockQuerySupportedRateRequest, ___E> for &'a ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockQuerySupportedRateRequest, ___E> for ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockQuerySupportedRateRequest, ___E> for ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ClockQuerySupportedRateRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ClockQuerySupportedRateRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ClockQuerySupportedRateRequest, ___E> for ClockQuerySupportedRateRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<ClockQuerySupportedRateRequest, ___E> for ClockQuerySupportedRateRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
impl FromWire<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateRequest, Self>
Sourcefn from_wire(wire: ClockQuerySupportedRateRequest) -> Self
fn from_wire(wire: ClockQuerySupportedRateRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
impl FromWireRef<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
Sourcefn from_wire_ref(wire: &ClockQuerySupportedRateRequest) -> Self
fn from_wire_ref(wire: &ClockQuerySupportedRateRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ClockQuerySupportedRateRequest
impl IntoNatural for ClockQuerySupportedRateRequest
Sourcetype Natural = ClockQuerySupportedRateRequest
type Natural = ClockQuerySupportedRateRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ClockQuerySupportedRateRequest
impl Wire for ClockQuerySupportedRateRequest
Sourcetype Narrowed<'de> = ClockQuerySupportedRateRequest
type Narrowed<'de> = ClockQuerySupportedRateRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.